@@ -6,6 +6,7 @@ from arthur_client.api_bindings.api.alerts_v1_api import AlertsV1Api
 from arthur_client.api_bindings.api.authorization_v1_api import AuthorizationV1Api
 from arthur_client.api_bindings.api.connector_schemas_v1_api import ConnectorSchemasV1Api
 from arthur_client.api_bindings.api.connectors_v1_api import ConnectorsV1Api
+from arthur_client.api_bindings.api.custom_aggregation_tests_v1_api import CustomAggregationTestsV1Api
 from arthur_client.api_bindings.api.custom_aggregations_v1_api import CustomAggregationsV1Api
 from arthur_client.api_bindings.api.data_plane_associations_v1_api import DataPlaneAssociationsV1Api
 from arthur_client.api_bindings.api.data_planes_v1_api import DataPlanesV1Api
@@ -23,6 +24,7 @@ from arthur_client.api_bindings.api.projects_v1_api import ProjectsV1Api
 from arthur_client.api_bindings.api.registration_v1_api import RegistrationV1Api
 from arthur_client.api_bindings.api.roles_v1_api import RolesV1Api
 from arthur_client.api_bindings.api.tasks_v1_api import TasksV1Api
+from arthur_client.api_bindings.api.unregistered_agents_v1_api import UnregisteredAgentsV1Api
 from arthur_client.api_bindings.api.upsolve_v1_api import UpsolveV1Api
 from arthur_client.api_bindings.api.users_v1_api import UsersV1Api
 from arthur_client.api_bindings.api.webhooks_v1_api import WebhooksV1Api
